﻿# IMPORTANT: Before releasing this package, copy/paste the next 2 lines into PowerShell to remove all comments from this file:
#   $f='c:\path\to\thisFile.ps1'
#   gc $f | ? {$_ -notmatch "^\s*#"} | % {$_ -replace '(^.*?)\s*?[^``]#.*','$1'} | Out-File $f+".~" -en utf8; mv -fo $f+".~" $f

$ErrorActionPreference = 'Stop'; # stop on all errors

function Write-DependencyInstallInformation([psobject] $customParameters, [string] $td) {
  $json = get-content "$($td)\dependencies.json"
  $dependencies = (($json) -join "`n") | convertfrom-json
  # FML, this is how you do null-coalescing in powerhell
  $sdkVersion = ($customParameters.sdkVersion, $dependencies.defaults.sdkVersion, "v9" -ne $null)[0]
  if ($sdkVersion) {
    write-host "To install dependencies for $($sdkVersion), run the following inside an administrator prompt:"
    $forVersion = $dependencies.$sdkVersion
    foreach ($dependency in $forVersion) {
      $line = "choco install -y $($dependency.name)"
      if ($dependency.version) {
        $line += " -version $($dependency.version)"
      }
      if ($dependency.params) {
        $line += " -params $($dependency.params)"
      }
      write-host $line
    }
  }
}

$toolsDir = Split-Path -parent $MyInvocation.MyCommand.Definition
$paramsText = get-content "$($toolsDir)\params.txt"
$p = $paramsText.Split("`n")

$packageDir = Split-Path -parent $toolsDir
$binRoot = (Get-ToolsLocation) -replace "\\", "/"

Get-ChocolateyWebFile `
  -PackageName "spatial" `
  -FileFullPath "$($toolsDir)/spatial.exe" `
  -Url "$($p[0])" `
  -Checksum "$($p[1])" `
  -ChecksumType "$($p[2])" `
  -Url64bit "$($p[0])" `
  -Checksum64 "$($p[1])" `
  -Checksum64Type "$($p[2])" `

$packageParams = Get-PackageParameters($env:chocolateyPackageParameters)
Write-DependencyInstallInformation $packageParams $toolsDir

write-host "Updating to latest version of spatial.exe via ``spatial update --force``"
& $toolsDir\spatial.exe update --force
if ($LASTEXITCODE -ne 0) {
  write-warning @"
Running ``spatial update`` failed.

Check the output for the reason.

The most likely reasons this failed:
* The browser window failed to open

  To fix:
  - run ``spatial update --force``
  - paste the url it outputs to a browser window and sign in
  - if the command times out again, run it again after having signed in and it
  will succeed.

* The browser window opened but with a different persona (e.g. Chrome's "people"
  feature). Your computer's shell picks the last browser window that you touched
  to launch a web address in.

  To fix, either:
  - click on a browser window where you have signed in before
  - sign in to the browser window that was chosen
  then re-run ``spatial update --force``
"@
}

$safeDefaultCliStructureVersion = "v2"
$cliStructureVersion = ($packageParams.cliStructureVersion, $safeDefaultCliStructureVersion -ne $null)[0]
write-host "CLI structure version $cliStructureVersion"
$valid = @("v1", "v2")
if ($valid -notcontains $cliStructureVersion) {
  write-warning @"
Invalid CLI structure version parameter passed: '$cliStructureVersion'.

Defaulting to '$safeDefaultCliStructureVersion' for version.

To change this, run ``spatial config set cli-structure <version>``.
"@
  $cliStructureVersion = $safeDefaultCliStructureVersion
}
& $toolsDir\spatial.exe config set cli-structure "$cliStructureVersion"
if ($LASTEXITCODE -ne 0) {
  write-warning @"
Failed to set config cli-structure to '$cliStructureVersion'.

You can try yourself via ``$toolsDir\spatial.exe config set cli-structure $cliStructureVersion``.

If that fails, please ask for help from support in our support forum at:

https://forums.improbable.io/c/sup

(you will need to be signed in with your spatialos account to see that).
"@
}

write-host "Done."
